@@ -5,7 +5,17 @@ use warnings;
 use Carp;
 use Data::Dumper;
 use List::Util qw(first);
-use Parse::Eyapp::Base qw( lastval );
+
+# A strange way to say:
+#                use Parse::Eyapp::Base qw{lastval}; 
+# The reason is to support standalone modules
+BEGIN {
+  unless (Parse::Eyapp::Base->can('lastval')) {
+    require Parse::Eyapp::Base;
+  }
+  Parse::Eyapp::Base->import('lastval');
+}
+
 
 sub valid_keys {
   my %valid_args = @_;
